@@ -21,13 +21,5 @@ class ChatView(BrowserView):
 		"""
 		return self.template()
 
-	def getMember(self):
-		"""
-		"""
-		self.membership = getToolByName(self.context, 'portal_membership')
-		if not self.membership.isAnonymousUser():
-			minfo = self.membership.getMemberInfo()
-			return minfo['fullname'] or self.membership.getAuthenticatedMember()
-		return None
 	
 	
\ No newline at end of file
