@@ -28,8 +28,8 @@ class HelpdeskEditForm(base.EditForm):
 	"""Edit form for projects
 	"""
 	
-	form_fields = (form.Fields(IHelpdesk).select('title','description') +
-					form.Fields(IHelpdesk, for_display=True).select('botJid','botPassword','persistent'))
+	form_fields = (form.Fields(IHelpdesk).select('title','description','persistent') +
+					form.Fields(IHelpdesk, for_display=True).select('botJid','botPassword'))
 	
 	label = _(u"Edit jabber Helpdesk")
 	form_name = _(u"Helpdesk settings")
\ No newline at end of file
