@@ -5,7 +5,7 @@ from zope import interface
 class JabberHelpdeskKSSCommands(CommandSet):
 	interface.implements(IJabberHelpdeskKSSCommands)
 	
-	def resetScrollbar(self, selector):
-		command = self.commands.addCommand('resetScrollbar', selector)
-	def resetInput(self, selector):
-		command = self.commands.addCommand('resetInput', selector)
+	def jh_resetScrollbar(self, selector):
+		command = self.commands.addCommand('jh_resetScrollbar', selector)
+	def jh_resetInput(self, selector):
+		command = self.commands.addCommand('jh_resetInput', selector)
